import config


class Delete:

    def GET(self, id_product):
        result = config.model.get_products(int(id_product))
        return config.render.delete(result)

    def POST(self, id_product):
        form = config.web.input()
        config.model.delete_products(form['id_product'])
        raise config.web.seeother('/')



import web
import config
import json

class Api_table_name:
    #http://api_table_name?user_hash=12345
    def GET(self):
        user_data = web.input()
        user_hash = user_data.user_hash
        if user_hash == '12345': #user_hash
            result = config.model.get_all_table_name()
            table_name_json = []
            for row in result:
                t= dict(row)
                table_name_json.append(t)
            web.header('Content-Type', 'application/json')
        else:
            raise web.seeother('/404')
        return json.dumps(table_name_json)
    
    #http://api_table_name?user_hash=12345&primary_key=1
    def POST(self):
        user_data = web.input()
        user_hash = user_data.user_hash
        primary_key = user_data.primary_key

        print user_hash
        print primary_key
        if user_hash == '12345': #user_hash
            try:
                result = config.model.get_products(int(primary_key))
                print result
                table_name_json = []
                table_name_json.append(dict(result))
            except:
                table_name_json = '{}'
        else:
            raise web.seeother('/404')
        return json.dumps(table_name_json)



from setuptools import setup, find_packages  # Always prefer setuptools over distutils

long_description = """
Create basic MVC skeleton using Web.py microframework and Heroku ready:
Functions:
    bootstrap - frontend framework
    jquery - js framework
    scheme.sql - MySQL demo database
    api - Restfull API
    ssl - HTTPS conection
    requirements.txt - Heroku requirements
    Procfile - Heroku config
"""

setup(
    name="kuorra",
    version="0.3.0",
    description="Create basic MVC skeleton using Web.py microframework",

    long_description=long_description,
    
    author="Salvador Hernandez Mendoza",
    
    author_email="salvadorhm@gmail.com",
    
    license="GPLv3",
    
    url="https://github.com/salvadorhm/kuorra",
    
    download_url="https://github.com/salvadorhm/kuorra",
    
    classifiers=['Development Status :: 4 - Beta',
                'Intended Audience :: Developers',
                'Topic :: Software Development',
                'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
                'Programming Language :: Python :: 2.7'],
    keywords="mvc web.py mysql heroku bootstrap jquery ssl api restful",
    install_requires=["web.py==0.38", "MySQL-python==1.2.5", "pyOpenSSL==16.2.0"],
    zip_safe=False,

    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*",
                                    "tests", "*tests*"]),
    entry_points={'console_scripts': ['kuorra=kuorra.kuorra:main'],
                },
    package_data={"kuorra": [
            "__init__.py",
            "__main__.py",
            "kuorra.py",
            "model_generator.py",
            "api_generator.py",
            "plugin/model_master.py",
            "plugin/api_master.py",
            "plugin/api_master_cool.py",
            "mvc/__init__.py",
            "mvc/app.py",
            "mvc/Procfile",
            "mvc/requirements.txt",
            "mvc/Readme.md",
            "mvc/ssl",
            "mvc/ssl/server.crt",
            "mvc/ssl/server.csr",
            "mvc/ssl/server.key",
            "mvc/application/__init__.py",
            "mvc/application/controllers/__init__.py",
            "mvc/application/controllers/products/config.py",
            "mvc/application/controllers/products/delete.py",
            "mvc/application/controllers/products/edit.py",
            "mvc/application/controllers/products/index.py",
            "mvc/application/controllers/products/__init__.py",
            "mvc/application/controllers/products/insert.py",
            "mvc/application/controllers/products/view.py",
            "mvc/application/models/config.py",
            "mvc/application/models/__init__.py",
            "mvc/application/models/model_products.py",
            "mvc/application/views/__init__.py",
            "mvc/application/views/products/delete.html",
            "mvc/application/views/products/edit.html",
            "mvc/application/views/products/index.html",
            "mvc/application/views/products/__init__.py",
            "mvc/application/views/products/insert.html",
            "mvc/application/views/products/master.html",
            "mvc/application/views/products/view.html",
            "mvc/application/api/__init__.py",
            "mvc/application/api/products/__init__.py",
            "mvc/application/api/products/api_products.py",
            "mvc/application/api/products/config.py",
            "mvc/data/schema.sql",
            "mvc/static/css/bootstrap.css",
            "mvc/static/css/index.html",
            "mvc/static/files/default.jpg",
            "mvc/static/fonts/glyphicons-halflings-regular.eot",
            "mvc/static/fonts/glyphicons-halflings-regular.svg",
            "mvc/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc/static/fonts/glyphicons-halflings-regular.woff",
            "mvc/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc/static/fonts/index.html",
            "mvc/static/js/bootstrap.js",
            "mvc/static/js/index.html",
            "mvc/static/js/jquery.js"]}
)